define("customBlocks_a4", [
  "blocklylib"
  ,"./blockly/msg"
  ,"./blockly/constants"
  ,"./blockly/context-menus"
  ,"./blockly/io"
  ,"./blockly/colors"
  ,"./blockly/block-utils"
  ,"./blockly/variables"
  ,"./blockly/field-variable"
], function (BlocklyLib, msg, constants, contextMenus, io, colors, blockUtils, variables, FieldVariable) {

var blockDefs = BlocklyLib.Blocks;

//READ VOLTAGE : Loupiot
blockDefs['picaxe_a4_loupiot_voltage'] = {
  init: function () {
    this.setHelpUrl('http://a4.fr/wiki/index.php/Accueil');
    this.setColour(colors.INPUT);
    this.appendDummyInput()
        .appendField(msg.get("A4_LOUPIOT_VOLTAGE"))
        .appendField(new FieldVariable(variables.defaultVarName, variables.validateVarName), "NAME")
    this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('A4 Loupiot');
    this.customContextMenu = contextMenus.customContextMenu;
    this.onchange = blockUtils.checkInputs;
    blockUtils.newBlock(this);
  },
  getVars: function () {
    return variables.getAll(this, ["NAME"]);
  },
  renameVar: function (oldName, newName) {
    return variables.rename(this, ["NAME"], oldName, newName);
  }
};

//BLUETOOTH RX:
blockDefs['picaxe_a4_bluetooth_rx'] = {
  init: function () {
    this.setHelpUrl('http://a4.fr/wiki/index.php/Accueil');
    this.setColour(colors.SERIAL_INPUT);
    this.appendDummyInput()
        .appendField(msg.get("A4_RECEIVE_BLUETOOTH_DATA"))
        //NB local subclass
        .appendField(new FieldVariable(variables.defaultVarName, variables.validateVarName), "NAME")
    this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('');
    this.customContextMenu = contextMenus.customContextMenu;
    blockUtils.newBlock(this);
  },
  getVars: function() {
    return variables.getAll(this, ["NAME"]);
  },
  renameVar: function(oldName, newName) {
    return variables.rename(this, ["NAME"], oldName, newName);
  },
  onchange: function() {
    io.checkHSerialType(this);
  }
};

//BLUETOOTH TX:
blockDefs['picaxe_a4_bluetooth_tx'] = {
  init: function () {
    this.setHelpUrl('http://a4.fr/wiki/index.php/Accueil');
    this.setColour(colors.SERIAL_OUTPUT);
    this.appendDummyInput()
        .appendField(msg.get("A4_SEND"));
    this.appendValueInput("VALUE").setCheck([constants.TYPES.VAL, constants.TYPES.VAR]);
    this.appendDummyInput()
        .appendField(msg.get("A4_BY_BLUETOOTH"));
    this.setInputsInline(true);
    this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('');
    this.customContextMenu = contextMenus.customContextMenu;
    this.onchange = blockUtils.checkInputs;
    blockUtils.newBlock(this);
  },
  onchange: function() {
    io.checkHSerialType(this);
  }
};

// OUTPUT : SET MOTOR [MOTOR] TO [DIRECTION]
blockDefs['picaxe_a4_portal'] = {
  init: function () {
    this.setHelpUrl('http://a4.fr/wiki/index.php/Accueil');
    this.setColour(colors.OUTPUT);
    this.appendDummyInput()
        .appendField(new BlocklyLib.FieldDropdown([
            [msg.get("A4_PORTAL_OPEN"), "OPEN"],
            [msg.get("A4_PORTAL_CLOSE"), "CLOSE"],
            [msg.get("A4_PORTAL_STOP"), "STOP"]
        ]), "DIRECTION")
    .appendField(msg.get("A4_PORTAL_MOTOR"));
    this.setInputsInline(true);
    this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('A4 Portail');
    this.customContextMenu = contextMenus.customContextMenu;
    blockUtils.newBlock(this);
  }
};


});
